@@ -289,7 +289,7 @@ class StoreSpec(object):
             "sense": _set_sense,
         }
 
-        skip_with_classes: list = [
+        skip_with_classes: List[Any] = [
             (i, []) for i in skip_classes if i not in classes
         ] + list(classes)
         self.classes = [i[0] for i in skip_with_classes]
