@@ -68,8 +68,13 @@ def _may_have_args(obj) -> bool:
 
 
 def _write_component(
-    obj_dict: dict, obj, store_spec: StoreSpec, count=None, lookup=None, suffixes=None
-) -> None:
+    obj_dict: Dict[str, Dict[str, Any]],
+    obj,
+    store_spec: StoreSpec,
+    count,
+    lookup,
+    suffixes,
+):
     """
     Writes a component state to the save dictionary under a key given by the
     components name.
@@ -84,10 +89,6 @@ def _write_component(
     Returns:
         None
     """
-    if lookup is None:
-        lookup = {}
-    if suffixes is None:
-        suffixes = []
 
     # Get the component name, doesn't need to be fully qualified or unique because
     # we are storing the state in a hierarchy structure
@@ -319,8 +320,8 @@ def to_json(
     if metadata is None:
         metadata = {}
 
-    suffixes: list = []
-    lookup: dict = {}
+    suffixes: List[dict] = list()
+    lookup: Dict[int, int] = dict()
     count: Counter = Counter()
     start_time = time.time()
     if store_spec is None:
@@ -351,16 +352,16 @@ def to_json(
     if file_name is not None:
         if gz:
             with gzip.open(file_name, "w") as f:
-                json.dump(obj_dict, f, **dump_kw)  # type: ignore
+                json.dump(obj_dict, f, **dump_kw)
         else:
             with open(file_name, "w") as f:
-                json.dump(obj_dict, f, **dump_kw)  # type: ignore
+                json.dump(obj_dict, f, **dump_kw)
     file_time = time.time()
     performance_dict["time_to_write_file"] = file_time - dict_time
 
     if return_dict:
         return obj_dict
     elif return_json_string:
-        return json.dumps(obj_dict, **dump_kw)  # type: ignore
+        return json.dumps(obj_dict, **dump_kw)  # type: ignore[return-value]
     else:
         return None
