@@ -1,4 +1,5 @@
 from typing import List
+
 import numpy as np
 
 
@@ -8,5 +9,5 @@ def get_rand_adjacency_matrix(num_vertices: int) -> List[List[bool]]:
         for j in range(num_vertices):
             if i > j:
                 adjacency_matrix[i, j] = adjacency_matrix[j, i]
-    adjacency_matrix -= np.diag(np.diag(adjacency_matrix))
+    adjacency_matrix -= np.diag(np.diag(adjacency_matrix))  # type: ignore[no-untyped-call]
     return adjacency_matrix.tolist()
