@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from typing import Dict, List, Optional, Union
 
 import pydantic
 
@@ -27,13 +27,13 @@ class EntanglingLayersArgs(CustomAnsatzArgs):
 
 class RandomArgs(CustomAnsatzArgs):
     gate_count: int = 100
-    gate_probabilities: dict = {"cx": 0.5, "u": 0.5}
-    random_seed: Union[int, None] = None
+    gate_probabilities: Dict[str, float] = {"cx": 0.5, "u": 0.5}
+    random_seed: Optional[int] = None
 
 
 class RandomTwoQubitGatesArgs(CustomAnsatzArgs):
     random_two_qubit_gate_count_factor: float = 1.0
-    random_seed: Union[int, None] = None
+    random_seed: Optional[int] = None
 
 
 class TwoLocalArgs(CustomAnsatzArgs):
