@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Optional
+from typing import Dict, Optional
 
 import pydantic
 
@@ -19,14 +19,15 @@ class UnaryOpParams(FunctionParams):
 
     def create_io_enums(self):
         output_name = self.output_name if self.output_name else DEFAULT_OUT_NAME
-        self._output_enum = Enum("BinaryOpOutputs", {output_name: output_name})
-
         arg_name = self.arg.name if self.arg.name else DEFAULT_ARG_NAME
 
-        self._input_enum = Enum(
-            "UnaryOpInputs",
-            {arg_name: arg_name},
-        )
+        output_name_dict: Dict[str, str] = {output_name: output_name}
+        input_name_dict = {arg_name: arg_name}
+        if not self.inplace:
+            output_name_dict.update(input_name_dict)
+
+        self._output_enum = Enum("BinaryOpOutputs", output_name_dict)
+        self._input_enum = Enum("UnaryOpInputs", input_name_dict)
 
     class Config:
         arbitrary_types_allowed = True
