@@ -1,6 +1,6 @@
 from typing import Optional
 
-from classiq_interface.generator.arithmetic import ArithmeticOracle
+from classiq_interface.generator.arith.arithmetic import ArithmeticOracle
 from classiq_interface.generator.function_params import FunctionParams
 from classiq_interface.generator.state_preparation import StatePreparation
 
@@ -11,8 +11,8 @@ class GroverOperator(FunctionParams):
     diffuser: Optional[str] = None
 
     def create_io_enums(self):
-        self._input_names = self.oracle._input_names
-        self._output_names = self.oracle._input_names
+        self._input_enum = self.oracle._input_enum
+        self._output_enum = self.oracle._input_enum
 
     class Config:
         extra = "forbid"
