@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Dict, Type, Union
 
 from classiq_interface.hybrid.encoding_type import EncodingType
 from classiq_interface.hybrid.mht_input import MHTInput
@@ -7,14 +7,14 @@ from classiq_interface.hybrid.mvc_input import MVCInput
 from classiq_interface.hybrid.problem_input import OptimizationProblemName, ProblemInput
 from classiq_interface.hybrid.tsp_input import TSPInput
 
-PROBLEM_INPUT_MAPPING: dict = {
+PROBLEM_INPUT_MAPPING: Dict[OptimizationProblemName, Type[ProblemInput]] = {
     OptimizationProblemName.TSP: TSPInput,
     OptimizationProblemName.MVC: MVCInput,
     OptimizationProblemName.MHT: MHTInput,
     OptimizationProblemName.MhtQaoa: MhtQaoaInput,
 }
 
-ENCODING_TYPE_DEFAULT: dict = {
+ENCODING_TYPE_DEFAULT: Dict[Type[ProblemInput], EncodingType] = {
     TSPInput: EncodingType.NODES,
     MVCInput: EncodingType.DICKE,
     MHTInput: EncodingType.SERIAL,
@@ -24,8 +24,10 @@ ENCODING_TYPE_DEFAULT: dict = {
 for e in OptimizationProblemName:
     assert e in PROBLEM_INPUT_MAPPING, "verify all problem inputs are accessible"
 
-for e in PROBLEM_INPUT_MAPPING.values():
-    assert e in ENCODING_TYPE_DEFAULT, "verify all problem inputs are accessible"
+for e in PROBLEM_INPUT_MAPPING:
+    assert (
+        PROBLEM_INPUT_MAPPING[e] in ENCODING_TYPE_DEFAULT
+    ), "verify all problem inputs are accessible"
 
 
 def parse_problem_input(problem: Union[dict, ProblemInput]) -> ProblemInput:
