@@ -1,8 +1,7 @@
 from enum import Enum
-from typing import Optional, List, Union
+from typing import List, Optional, Union
 
 import pydantic
-from classiq_interface.generator.custom_gates import ValidGateName
 
 
 class UnrollerType(str, Enum):
@@ -19,7 +18,7 @@ class TranspilationPreferences(pydantic.BaseModel):
         description="Whether the transpiled circuit is part of a bigger circuit. "
         "This enables optimizations with assumptions on the start and end conditions of the circuit.",
     )
-    unroller: Optional[Union[UnrollerType, List[ValidGateName]]] = pydantic.Field(
+    unroller: Optional[Union[UnrollerType, List[str]]] = pydantic.Field(
         default=None,
         description=f"Unroll {UnrollerType.THREE_QUBIT_GATES} or unroll to specific basis gates.",
     )
