@@ -2,7 +2,7 @@ import base64
 import enum
 import io
 from datetime import datetime, time
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import matplotlib.pyplot as plt
 import pydantic
@@ -159,7 +159,7 @@ class VQESolverResult(VQASolverResult):
 
 
 class QAOASolverResult(VQASolverResult):
-    preprocessed_graph: Dict
+    preprocessed_graph: Dict[str, Any]
     solution_segment: List[Tuple[int, ...]]
 
 
